@@ -57,7 +57,7 @@ class LogEntryAdmin(admin.ModelAdmin):
             ct = obj.content_type
             link = u'<a href="%s">%s</a>' % (
                 reverse('admin:%s_%s_change' % (ct.app_label, ct.model), args=[obj.object_id]),
-                escape(obj.object_repr),
+                escape(obj.object_repr.replace('{', '(').replace('}', ')')),
             )
         return format_html(link)
 
