@@ -35,7 +35,7 @@ def changed_message(changed_field, old, new):
                         message += f"field: {field}"
                         old_field = eval('old["fields"]["' + field + '"]')
                         new_field = eval('new.' + field)
-                        message += f", old: {old_field[:50]}, new: {new_field[:50]}\n"
+                        message += f", old: {str(old_field)[:50]}, new: {str(new_field)[:50]}\n"
                     except:
                         pass
         if "added" in i:
